@@ -2,57 +2,66 @@ package Class::Autouse;
 
 # See POD at end of file for documentation
 
-### Memory Overhead: 180K
+### Memory Overhead: 396K
 
 use 5.005;
 use strict;
-no strict 'refs'; # We do a LOT of bad ref stuff
+no strict 'refs'; # We _really_ abuse refs :)
 use UNIVERSAL ();
 
+# Debugging
+# Handle debugging switch via a constant to allow debugging
+# to be optimised out at compile time if not needed.
+use vars qw{$DEBUG};
+use constant DEBUG => $DEBUG;
+print "Class::Autouse::autoload -> Debugging Activated.\n" if defined DEBUG;
+
 # Become an exporter so we don't get complaints when we act as a pragma.
-# I don't fully understand the reason for this, but it works.
+# I don't fully understand the reason for this, but it works and I can't
+# recall how to replicate the problem, so leaving it in to avoid any
+# possible reversion. Besides, so many things use Exporter it should
+# be practically free to do this.
 use base 'Exporter';
 
 # Load required modules
+# Luckily, these are so common they are basically free
 use Carp       ();
 use File::Spec ();
 use List::Util ();
 
 # Globals
-use vars qw{$VERSION $DEBUG $DEVEL $SUPERLOAD};    # Load environment
-use vars qw{$HOOKS %chased %loaded %special %bad}; # Working data
-use vars qw{*_UNIVERSAL_can};                      # Subroutine storage
+use vars qw{ $VERSION $DEVEL $SUPERLOAD $NOSTAT }; # Load environment
+use vars qw{ %SPECIAL %LOADED %BAD              }; # Special cases
+use vars qw{ $HOOKS %chased *_UNIVERSAL_can     }; # Working information
+
+# Compile-time Initialisation and Optimisation
 BEGIN {
-	$VERSION = '1.16';
-	$DEBUG   = 0;
+	$VERSION = '1.24';
 
 	# We play with UNIVERSAL::can at times, so save a backup copy
 	*_UNIVERSAL_can = *UNIVERSAL::can{CODE};
 
-	# Start with devel mode off.
-	$DEVEL = 0;
-
 	# We always start with the superloader off
 	$SUPERLOAD = 0;
 
+	# Disable stating for situations where modules are on remote disks
+	$NOSTAT = 0;
+
 	# AUTOLOAD hook counter
 	$HOOKS = 0;
 
-	# Anti-loop protection. "Have we tried to autoload a method before?"
-	# Contains fully referenced sub names.
-	%chased = ();
-
 	# ERRATA
 	# Special classes are internal and should be left alone.
 	# Loaded modules are those already loaded by us.
 	# Bad classes are those that are incompatible with us.
-	%special = map { $_ => 1 } qw{CORE main ARRAY HASH SCALAR REF UNIVERSAL};
-	%loaded  = map { $_ => 1 } qw{UNIVERSAL Exporter Carp File::Spec};
-	%bad     = map { $_ => 1 } qw{IO::File};
-}
+	%SPECIAL = map { $_ => 1 } qw{ CORE main ARRAY HASH SCALAR REF UNIVERSAL };
+	%LOADED  = map { $_ => 1 } qw{ UNIVERSAL Exporter Carp File::Spec        };
+	%BAD     = map { $_ => 1 } qw{ IO::File                                  };
 
-# Define prototypes
-sub _cry($);
+	# "Have we tried to autoload a method before?"
+	# Anti-loop protection. Contains fully referenced sub names
+	%chased = ();
+}
 
 
 
@@ -64,7 +73,7 @@ sub _cry($);
 # Developer mode flag.
 # Cannot be turned off once turned on.
 sub devel {
-	_debug(\@_, 1) if $DEBUG;
+	_debug(\@_, 1) if defined DEBUG;
 
 	# Enable if not already
 	return 1 if $DEVEL;
@@ -83,7 +92,7 @@ sub devel {
 # The process here is to replace the &UNIVERSAL::AUTOLOAD sub
 # ( which is just a dummy by default ) with a flexible class loader.
 sub superloader {
-	_debug(\@_, 1) if $DEBUG;
+	_debug(\@_, 1) if defined DEBUG;
 
 	unless ( $SUPERLOAD ) {
 		# Overwrite UNIVERSAL::AUTOLOAD and catch any
@@ -110,7 +119,7 @@ sub autouse {
 	# Ignore calls with no arguments
 	return 1 unless @_;
 
-	_debug(\@_) if $DEBUG;
+	_debug(\@_) if defined DEBUG;
 
 	foreach my $class ( grep { $_ } @_ ) {
 		# Control flag handling
@@ -121,16 +130,15 @@ sub autouse {
 			} elsif ( $class eq ':devel' ) {
 				# Turn on devel mode
 				Class::Autouse->devel(1);
-			} elsif ( $class eq ':debug' ) {
-				# Turn on debugging
-				$DEBUG = 1;
-				print _call_depth(1) . "Class::Autouse::autoload -> Debugging Activated.\n";
+			} elsif ( $class eq ':nostat' ) {
+				# Disable stat checks
+				$NOSTAT = 1;
 			}
 			next;
 		}
 
 		# Load now if in devel mode, or if its a bad class
-		if ( $DEVEL || $bad{$class} ) {
+		if ( $DEVEL || $BAD{$class} ) {
 			Class::Autouse->load( $class );
 			next;
 		}
@@ -138,9 +146,9 @@ sub autouse {
 		# Does the file for the class exist?
 		my $file = _class_file($class);
 		next if exists $INC{$file};
-		unless ( _file_exists($file) ) {
+		unless ( $NOSTAT or _file_exists($file) ) {
 			my $inc = join ', ', @INC;
-			_cry "Can't locate $file in \@INC (\@INC contains: $inc)";
+			_cry("Can't locate $file in \@INC (\@INC contains: $inc)");
 		}
 
 		# Don't actually do anything if the superloader is on.
@@ -170,10 +178,10 @@ sub import { shift->autouse(@_) }
 
 # Completely load a class ( The class and all its dependencies ).
 sub load {
-	_debug(\@_, 1) if $DEBUG;
+	_debug(\@_, 1) if defined DEBUG;
 
-	my $class = $_[1] or _cry 'No class name specified to load';
-	return 1 if $loaded{$class};
+	my $class = $_[1] or _cry('No class name specified to load');
+	return 1 if $LOADED{$class};
 
 	# Load the entire ISA tree
 	my @stack  = ( $class );
@@ -183,7 +191,7 @@ sub load {
 		next if $seen{$c}++;
 
 		# Ensure class is loaded
-		_load($c) unless $loaded{$c};
+		_load($c) unless $LOADED{$c};
 
 		# Add the class to the search list,
 		# and add the @ISA to the load stack.
@@ -199,7 +207,7 @@ sub load {
 # Is a particular class installed in out @INC somewhere
 # OR is it loaded in our program already
 sub class_exists {
-	_debug(\@_, 1) if $DEBUG;
+	_debug(\@_, 1) if defined DEBUG;
 	_namespace_occupied($_[1]) or _file_exists($_[1]);
 }
 
@@ -209,7 +217,7 @@ sub class_exists {
 # Returns 0 if the class is not loaded ( or autouse'd )
 # Returns 1 if the class can be used.
 sub can_call_methods {
-	_debug(\@_, 1) if $DEBUG;
+	_debug(\@_, 1) if defined DEBUG;
 	_namespace_occupied($_[1]) or exists $INC{_class_file($_[1])};
 }
 
@@ -218,7 +226,7 @@ sub can_call_methods {
 
 # Autouse not only a class, but all others below it.
 sub autouse_recursive {
-	_debug(\@_, 1) if $DEBUG;
+	_debug(\@_, 1) if defined DEBUG;
 
 	# Just load if in devel mode
 	return Class::Autouse->load_recursive($_[1]) if $DEVEL;
@@ -232,7 +240,7 @@ sub autouse_recursive {
 
 # Load not only a class and all others below it
 sub load_recursive {
-	_debug(\@_, 1) if $DEBUG;
+	_debug(\@_, 1) if defined DEBUG;
 
 	# Load the parent class, and its children
 	foreach ( $_[1], _child_classes($_[1]) ) {
@@ -254,15 +262,15 @@ sub load_recursive {
 
 # Get's linked via the symbol table to any AUTOLOADs are required
 sub _AUTOLOAD {
-	_debug(\@_, 0, ", AUTOLOAD = '$Class::Autouse::AUTOLOAD'") if $DEBUG;
+	_debug(\@_, 0, ", AUTOLOAD = '$Class::Autouse::AUTOLOAD'") if defined DEBUG;
 
 	# Loop detection ( Just in case )
-	my $method = $Class::Autouse::AUTOLOAD or _cry 'Missing method name';
-	_cry "Undefined subroutine &$method called" if ++$chased{ $method } > 10;
+	my $method = $Class::Autouse::AUTOLOAD or _cry('Missing method name');
+	_cry("Undefined subroutine &$method called") if ++$chased{ $method } > 10;
 
 	# Don't bother with special classes
 	my ($class, $function) = $method =~ m/^(.*)::(.*)$/s;
-	_cry "Undefined subroutine &$method called" if $special{$class};
+	_cry("Undefined subroutine &$method called") if $SPECIAL{$class};
 
 	# Load the class and it's dependancies, and get the search path
 	my @search = Class::Autouse->load($class);
@@ -281,18 +289,22 @@ sub _AUTOLOAD {
 	}
 
 	# Can't find the method anywhere. Throw the same error Perl does.
-	_cry "Can't locate object method \"$function\" via package \"$class\"";
+	_cry("Can't locate object method \"$function\" via package \"$class\"");
 }
 
 # This just handles the call and does nothing
-sub _DESTROY { _debug(\@_) if $DEBUG }
+sub _DESTROY {
+	_debug(\@_) if defined DEBUG;
+}
 
 # This is the replacement for UNIVERSAL::can
 sub _can {
 	my $class = ref $_[0] || $_[0] || return undef;
 
 	# Shortcut for the most likely cases
-	goto &_UNIVERSAL_can if $loaded{$class} or defined @{"${class}::ISA"};
+	if ( $LOADED{$class} or defined @{"${class}::ISA"} ) { 
+		goto &_UNIVERSAL_can;
+	}
 
 	# Does it look like a package?
 	$class =~ /^[^\W\d]\w*(?:(?:'|::)[^\W\d]\w*)*$/o or return undef;
@@ -309,7 +321,7 @@ sub _can {
 	} elsif ( _namespace_occupied($class) ) {
 		# Superloader is on, but there is something already in the class
 		# This can't be the autouse loader, because we would have caught
-		# that case already
+		# that case already.
 		$load = 0;
 	} else {
 		# The rules of the superloader say we assume loaded unless we can
@@ -318,10 +330,10 @@ sub _can {
 	}
 
 	# If needed, load the class and all its dependencies.
-	# UNIVERSAL::can never dies, so we shouldn't either.
-	# Ignore, errors. If something goes wrong,
-	# let the real UNIVERSAL::can have a short at it anyway.
-	eval { Class::Autouse->load($class) } if $load;
+	if ( $load ) {
+		eval { Class::Autouse->load($class) };
+		die $@ if $@;
+	}
 
 	# Hand off to the real UNIVERSAL::can
 	goto &_UNIVERSAL_can;
@@ -336,18 +348,18 @@ sub _can {
 
 # Load a single class
 sub _load ($) {
-	_debug(\@_) if $DEBUG;
+	_debug(\@_) if defined DEBUG;
 
 	# Don't attempt to load special classes
-	my $class = shift or _cry 'Did not specify a class to load';
-	return 1 if $special{$class};
+	my $class = shift or _cry('Did not specify a class to load');
+	return 1 if $SPECIAL{$class};
 
 	# Run some checks
 	my $file = _class_file($class);
 	if ( defined $INC{$file} ) {
 		# If the %INC lock is set to any other value, the file is
 		# already loaded. We do not need to do anything.
-		return $loaded{$class} = 1 if $INC{$file} ne 'Class::Autouse';
+		return $LOADED{$class} = 1 if $INC{$file} ne 'Class::Autouse';
 
 		# Because we autoused it earlier, we know the file for this
 		# class MUST exist.
@@ -358,25 +370,28 @@ sub _load ($) {
 	} elsif ( ! _file_exists($file) ) {
 		# File doesn't exist. We might still be OK, if the class was
 		# defined in some other module that got loaded a different way.
-		return $loaded{$class} = 1 if _namespace_occupied($class);
+		return $LOADED{$class} = 1 if _namespace_occupied($class);
 		my $inc = join ', ', @INC;
-		_cry "Can't locate $file in \@INC (\@INC contains: $inc)";
+		_cry("Can't locate $file in \@INC (\@INC contains: $inc)");
 	}
 
 	# Load the file
-	print _call_depth(1) . "  Class::Autouse::load -> Loading in $file\n" if $DEBUG;
-	eval { CORE::require $file }; _cry $@ if $@;
+	print _call_depth(1) . "  Class::Autouse::load -> Loading in $file\n" if defined DEBUG;
+	eval {
+		CORE::require($file);
+	};
+	_cry($@) if $@;
 
 	# Give back UNIVERSAL::can if there are no other hooks
 	--$HOOKS or _UPDATE_CAN();
 
-	$loaded{$class} = 1;
+	$LOADED{$class} = 1;
 }
 
 # Find all the child classes for a parent class.
 # Returns in the list context.
 sub _child_classes ($) {
-	_debug(\@_) if $DEBUG;
+	_debug(\@_) if defined DEBUG;
 
 	# Find where it is in @INC
 	my $base_file = _class_file(shift);
@@ -438,7 +453,7 @@ sub _child_classes ($) {
 # Does a class or file exists somewhere in our include path. For
 # convenience, returns the unresolved file name ( even if passed a class )
 sub _file_exists ($) {
-	_debug(\@_) if $DEBUG;
+	_debug(\@_) if defined DEBUG;
 
 	# What are we looking for?
 	my $file = shift or return undef;
@@ -457,7 +472,7 @@ sub _file_exists ($) {
 
 # Is a namespace occupied by anything significant
 sub _namespace_occupied ($) {
-	_debug(\@_) if $DEBUG;
+	_debug(\@_) if defined DEBUG;
 
 	# Handle the most likely case
 	my $class = shift or return undef;
@@ -465,7 +480,7 @@ sub _namespace_occupied ($) {
 
 	# Get the list of glob names, ignoring namespaces
 	foreach ( keys %{"${class}::"} ) {
-		next if /::$/;
+		next if substr($_, -2) eq '::';
 
 		# Only check for methods, since that's all that's reliable
 		return 1 if defined *{"${class}::$_"}{CODE};
@@ -475,12 +490,14 @@ sub _namespace_occupied ($) {
 }
 
 # For a given class, get the file name
-sub _class_file ($) { join( '/', split /(?:\'|::)/, shift ) . '.pm' }
+sub _class_file ($) {
+	join( '/', split /(?:\'|::)/, shift ) . '.pm';
+}
 
 # Establish our call depth
 sub _call_depth {
 	my $spaces = shift;
-	if ( $DEBUG and ! $spaces ) { _debug(\@_); }
+	if ( defined DEBUG and ! $spaces ) { _debug(\@_) }
 
 	# Search up the caller stack to find the first call that isn't us.
 	my $level = 0;
@@ -498,15 +515,17 @@ sub _call_depth {
 }
 
 # Die gracefully
-sub _cry ($) {
-	_debug() if $DEBUG;
-
+sub _cry {
+	_debug() if defined DEBUG;
 	local $Carp::CarpLevel;
 	$Carp::CarpLevel += _call_depth();
 	Carp::croak( $_[0] );
 }
 
 # Adaptive debug print generation
+BEGIN {
+	eval <<'END_DEBUG' if defined DEBUG;
+
 sub _debug {
 	my $args    = shift;
 	my $method  = !! shift;
@@ -518,10 +537,12 @@ sub _debug {
 		shift @mapped if $method;
 		$msg .= @mapped ? '( ' . ( join ', ', @mapped ) . ' )' : '()';
 	}
-
 	print "$msg$message\n";
 }
 
+END_DEBUG
+}
+
 
 
 
@@ -553,7 +574,7 @@ BEGIN {
 		$DEVEL = 1 if $ENV{MOD_PERL};
 	} else {
 		# Go into devel mode when prefork is enabled
-		$loaded{prefork} = 1;
+		$LOADED{prefork} = 1;
 		eval "prefork::notify( sub { Class::Autouse->devel(1) } )";
 		die $@ if $@;
 	}
@@ -567,10 +588,13 @@ __END__
 
 =head1 NAME
 
-Class::Autouse - Run-time class loading on first method call
+Class::Autouse - Run-time load a class the first time you call a method in it.
 
 =head1 SYNOPSIS
 
+  # Debugging (if you go that way) must be set before the first use
+  $Class::Autouse::DEBUG = 1;
+  
   # Load a class on method call
   use Class::Autouse;
   Class::Autouse->autouse( 'CGI' );
@@ -579,21 +603,39 @@ Class::Autouse - Run-time class loading on first method call
   # Use as a pragma
   use Class::Autouse qw{CGI};
 
-  # Turn on debugging
-  use Class::Autouse qw{:debug};
-
   # Turn on developer mode
   use Class::Autouse qw{:devel};
 
   # Turn on the Super Loader
   use Class::Autouse qw{:superloader};
+  
+  # Disable module-existance check, and thus one additional 'stat'
+  # per module, at autouse-time if loading modules off a remote
+  # network drive such as NFS or SMB.
+  use Class::Autouse qw{:nostat};
 
 =head1 DESCRIPTION
 
-Class::Autouse allows you to specify a class the will only load when a
+C<Class::Autouse> allows you to specify a class the will only load when a
 method of that class is called. For large classes that might not be used
-during the running of a program, such as Date::Manip, this can save
-you large amounts of memory, and decrease the script load time.
+during the running of a program, such as L<Date::Manip>, this can save
+you large amounts of memory, and decrease the script load time a great deal.
+
+=head2 Class, not Module
+
+The terminology "class loading" instead of "module loading" is used
+intentionally. Modules will only be loaded if they are acting as a class.
+
+That is, they will only be loaded during a Class-E<gt>method call. If you try
+to use a subroutine directly, say with C<Class::method()>, the class will
+not be loaded and a fatal error will mostly likely occur.
+
+This limitation is made to allow more powerfull features in other areas,
+because the module can focus on just loading the modules, and not have
+to deal with importing.
+
+And really, if you are doing OO Perl, you should be avoiding importing
+wherever possible.
 
 =head2 Use as a pragma
 
@@ -605,36 +647,18 @@ to load as the arguments. For example
 is equivalent to
 
    use Class::Autouse;
-   Class::Autouse->autouse( 'CGI' );
+   Class::Autouse->autouse( 'CGI'         );
    Class::Autouse->autouse( 'Data::Manip' );
-   Class::Autouse->autouse( 'This::That' );
-
-=head2 The Internal Debugger
-
-Given the C<:debug> pragma argument, Class::Autouse will dump
-detailed internal call information. This can be usefull when an
-error has occurred that may be a little difficult to debug, and
-some more inforamtion about when the problem has actually
-occurred is required. Debug messages are written to STDOUT, and
-will look something like
-
- Class::Autouse::autouse_recursive( 'Foo' )
-  Class::Autouse::_recursive( 'Foo', 'load' )
-   Class::Autouse::load( 'Foo' )
-   Class::Autouse::_child_classes( 'Foo' )
-   Class::Autouse::load( 'Foo::Bar' )
-    Class::Autouse::_file_exists( 'Foo/Bar.pm' )
-    Class::Autouse::load -> Loading in Foo/Bar.pm
-   Class::Autouse::load( 'Foo::More' )
-    etc...
+   Class::Autouse->autouse( 'This::That'  );
 
 =head2 Developer Mode
 
-Class::Autouse features a developer mode. In developer mode, classes
+C<Class::Autouse> features a developer mode. In developer mode, classes
 are loaded immediately, just like they would be with a normal 'use'
-statement (although the import sub isn't called). This allows error
-checking to be done while developing, at the expense of a larger
-memory overhead. Developer mode is turned on either with the
+statement (although the import sub isn't called).
+
+This allows error checking to be done while developing, at the expense of
+a larger memory overhead. Developer mode is turned on either with the
 C<devel> method, or using :devel in any of the pragma arguments.
 For example, this would load CGI.pm immediately
 
@@ -646,24 +670,47 @@ notation, and just comment or uncomment a single line to turn developer
 mode on or off. You can leave it on during development, and turn it
 off for speed reasons when deploying.
 
-=head2 Super Loader
+=head2 No-Stat Mode
 
-Turning on the Class::Autouse super loader allows you to automatically
-load ANY class without specifying it first. Thus, the following will work
-and is completely legal.
+For situations where a module exists on a remote disk or another relatively
+expensive location, you can call C<Class::Autouse> with the :nostat param
+to disable initial file existance checking at hook time.
+
+  # Disable autoload-time file existance checking
+  use Class::Autouse qw{:nostat};
+
+=head2 Super Loader Mode
+
+Turning on the C<Class::Autouse> super loader allows you to automatically
+load B<ANY> class without specifying it first. Thus, the following will
+work and is completely legal.
 
     use Class::Autouse qw{:superloader};
 
     print CGI->b('Wow!');
 
-The super loader can be turned on with either the Class::Autouse->superloader
-method, or the :superloader pragma argument.
+The super loader can be turned on with either the
+C<Class::Autouse-E<gt>>superloader> method, or the C<:superloader> pragma
+argument.
 
-=head2 Recursion
+Please note that unlike the normal one-at-a-time autoloading, the
+super-loader makes global changes, and so is not completely self-contained.
 
-As an alternative to the super loader, the autouse_recursive and
-load_recursive methods can be used to autouse or load an entire tree of
-classes. For example, the following would give you access to all the URI
+It has the potential to cause unintended effects at a distance. If you
+encounter unusual behaviour, revert to autousing one-at-a-time, or use
+the recursive loading.
+
+Use of the Super Loader is highly discouraged for widely distributed
+public applications or modules unless unavoidable. B<Do not use> just
+to be lazy and save a few lines of code.
+
+=head2 Recursive Loading
+
+As an alternative to the super loader, the C<autouse_recursive> and
+C<load_recursive> methods can be used to autouse or load an entire tree
+of classes.
+
+For example, the following would give you access to all the L<URI>
 related classes installed on the machine.
 
     Class::Autouse->autouse_recursive( 'URI' );
@@ -671,32 +718,51 @@ related classes installed on the machine.
 Please note that the loadings will only occur down a single branch of the
 include path, whichever the top class is located in.
 
-=head2 Class, not Module
-
-The terminology "Class loading" instead of "Module loading" is used
-intentionally. Modules will only be loaded if they are acting as a class.
-That is, they will only be loaded during a Class->method call. If you try
-do use a subroutine directly, say with C<Class::method()>, the class will
-not be loaded. This limitation is made to allow more powerfull features in
-other areas, because the module can focus on just loading the modules, and
-not have to deal with importing.
-
 =head2 mod_perl
 
-The methods that Class::Autouse uses are not compatible with mod_perl. In
-particular with reloader modules like Apache::Reload. Class::Autouse detects
-the presence of mod_perl and acts as normal, but will always load all
-classes immediately, equivalent to having developer mode enabled.
+The mechanism that C<Class::Autouse> uses is not compatible with L<mod_perl>.
+In particular with reloader modules like L<Apache::Reload>. C<Class::Autouse>
+detects the presence of mod_perl and acts as normal, but will always load
+all classes immediately, equivalent to having developer mode enabled.
 
 This is actually beneficial, as under mod_perl classes should be preloaded
 in the parent mod_perl process anyway, to prevent them having to be loaded
 by the Apache child classes. It also saves HUGE amounts of memory.
 
+=head2 prefork
+
+As for mod_perl, C<Class::Autouse> is compatible with the L<prefork> module,
+and all modules autoloaded will be loaded before forking correctly, when
+requested by L<prefork>.
+
+=head2 The Internal Debugger
+
+Class::Autouse provides an internal debugger, which can be used to debug
+any weird edge cases you might encounter when using it.
+
+If the C<$Class::Autouse::DEBUG> variable is true when C<Class::Autouse>
+is first loaded, debugging will be compiled in. This debugging prints
+output like the following to STDOUT.
+
+ Class::Autouse::autouse_recursive( 'Foo' )
+  Class::Autouse::_recursive( 'Foo', 'load' )
+   Class::Autouse::load( 'Foo' )
+   Class::Autouse::_child_classes( 'Foo' )
+   Class::Autouse::load( 'Foo::Bar' )
+    Class::Autouse::_file_exists( 'Foo/Bar.pm' )
+    Class::Autouse::load -> Loading in Foo/Bar.pm
+   Class::Autouse::load( 'Foo::More' )
+    etc...
+
+Please note that because this is optimised out if not used, you can
+no longer (since 1.20) enable debugging at run-time. This decision was
+made to remove a large number of unneeded branching and speed up loading.
+
 =head1 METHODS
 
-=head2 autouse $class
+=head2 autouse $class, ...
 
-The autouse method sets the class to be loaded as required.
+The autouse method sets one or more classes to be loaded as required.
 
 =head2 load $class
 
@@ -707,28 +773,34 @@ class, whereas as use effectively ignore the class, and not load it.
 
 =head2 devel
 
-The devel method sets development mode on (argument of 1) or off (argument of 0)
+The devel method sets development mode on (argument of 1) or off
+(argument of 0).
+
+If any classes have previously been autouse'd and not loaded when this
+method is called, they will be loaded immediately.
 
 =head2 superloader
 
-The superloader method turns on the super loader. Please note that once you
-have turned the superloader on, it cannot be turned off. This is due to
-code that might be relying on it being there not being able to autoload its
-classes when another piece of code decides they don't want it any more, and
-turns the superloader off.
+The superloader method turns on the super loader.
+
+Please note that once you have turned the superloader on, it cannot be
+turned off. This is due to code that might be relying on it being there not
+being able to autoload its classes when another piece of code decides
+they don't want it any more, and turns the superloader off.
 
 =head2 class_exists $class
 
-Handy method when doing the sort of jobs that Class::Autouse does. Given
+Handy method when doing the sort of jobs that C<Class::Autouse> does. Given
 a class name, it will return true if the class can be loaded ( i.e. in @INC ),
 false if the class can't be loaded, and undef if the class name is invalid.
 
 Note that this does not actually load the class, just tests to see if it can
-be loaded. Loading can still fail.
+be loaded. Loading can still fail. For a more comprehensive set of methods
+of this nature, see L<Class::Inspector>.
 
 =head2 autouse_recursive $class
 
-The same as the C<autouse> method, but autouses recursively
+The same as the C<autouse> method, but autouses recursively.
 
 =head2 load_recursive $class
 
@@ -745,7 +817,7 @@ For other issues, or commercial enhancement or support, contact the author.
 
 =head1 AUTHORS
 
-Adam Kennedy (Maintainer), L<http://ali.as/>, cpan@ali.as
+Adam Kennedy (Creator and Maintainer), L<http://ali.as/>, cpan@ali.as
 
 Rob Napier (No longer involved), rnapier@employees.org
 
@@ -755,7 +827,7 @@ L<autoload>, L<autoclass>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 - 2005 Adam Kennedy. All rights reserved.
+Copyright (c) 2002 - 2006 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
